<?php

namespace Drupal\month_year\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'year_month' field type.
 *
 * @FieldType(
 *   id = "year_month",
 *   label = @Translation("Month Year"),
 *   default_widget = "year_month_widget",
 *   default_formatter = "year_month_formatter"
 * )
 */
class YearMonth extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {

    return [
      'columns' => [
        'value' => [
          'type' => 'char',
          'length' => 7,
          'not null' => TRUE,
          'description' => 'To store the month year.',
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return $value === NULL || $value === '';
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(t('Month Year'));
    return $properties;
  }

}
